package example.app.server.core.classpath;

import java.net.URL;
import java.util.ArrayList;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
import org.eclipse.jdt.core.ClasspathContainerInitializer;
import org.eclipse.jdt.core.IClasspathContainer;
import org.eclipse.jdt.core.IClasspathEntry;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.jdt.launching.JavaRuntime;
import org.osgi.framework.Bundle;

import example.app.server.Activator;

public class ClasspathInitializer extends ClasspathContainerInitializer {

	public ClasspathInitializer() {
	}

	public void initialize(IPath containerPath, IJavaProject project)
			throws CoreException {
		InnerContainer container = new InnerContainer(containerPath);
		
		JavaCore.setClasspathContainer(containerPath, 
				new IJavaProject[] {project}, new IClasspathContainer[] {container}, null);

	}

	public IClasspathEntry[] getEntries(IPath path) {
		return new InnerContainer(path).getClasspathEntries();
	}

	public static class InnerContainer implements IClasspathContainer {
		private IPath path;
		public InnerContainer(IPath path) {
			this.path = path;
		}

		public IClasspathEntry[] getClasspathEntries() {
			String jar = path.segment(2) + ".jar";
			IPath p = new Path("serverLibs").append(path.segment(2) + ".jar");
			URL[] urls = FileLocator.findEntries(Activator.getDefault().getBundle(), p);
//			IClasspathEntry example = JavaRuntime.newArchiveRuntimeClasspathEntry(path).getClasspathEntry();
//			return new IClasspathEntry[] {example};
			try {
			if( urls.length == 1 ) {
				Bundle bundle = Activator.getDefault().getBundle();
				URL bundleURL = FileLocator.toFileURL(bundle.getEntry(""));
				IPath bundlePath = new Path(bundleURL.getFile());
				
				return new IClasspathEntry[] { 
						JavaRuntime.newArchiveRuntimeClasspathEntry(bundlePath.append(p)).getClasspathEntry()
				};
			}
			} catch( Throwable t ) { }
			return new IClasspathEntry[] { };
		}

		public String getDescription() {
			return "Example entries for facet: " + path.segment(2);
		}

		public int getKind() {
			return IClasspathContainer.K_APPLICATION;
		}

		public IPath getPath() {
			return path;
		}
		
		protected IClasspathEntry getEntry(IPath path) {
			return JavaRuntime.newArchiveRuntimeClasspathEntry(path).getClasspathEntry();
		}
		protected void addEntries(IPath folder, ArrayList list) {
			if( folder.toFile().exists()) {
				String[] files = folder.toFile().list();
				for( int i = 0; i < files.length; i++ ) {
					if( files[i].endsWith(".jar")) {
						list.add(getEntry(folder.append(files[i])));
					}
				}
			}
		}
	}

}
