package example.app.server.core.classpath;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.core.runtime.IAdapterFactory;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
import org.eclipse.jdt.core.IClasspathEntry;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.jdt.launching.IVMInstall;
import org.eclipse.jdt.launching.JavaRuntime;
import org.eclipse.jst.common.project.facet.core.IClasspathProvider;
import org.eclipse.wst.common.project.facet.core.IProjectFacetVersion;
import org.eclipse.wst.common.project.facet.core.runtime.IRuntimeComponent;

public class ProjectRuntimeClasspathProvider implements IClasspathProvider {

	public static final class Factory implements IAdapterFactory {
		private static final Class[] ADAPTER_TYPES = { IClasspathProvider.class };

		public Object getAdapter(final Object adaptable, final Class adapterType) {
			IRuntimeComponent rc = (IRuntimeComponent) adaptable;
			return new ProjectRuntimeClasspathProvider(rc);
		}

		public Class[] getAdapterList() {
			return ADAPTER_TYPES;
		}
	}

	private IRuntimeComponent rc;

	public ProjectRuntimeClasspathProvider() {
	}
	
	public ProjectRuntimeClasspathProvider(final IRuntimeComponent rc) {
		this.rc = rc;
	}

	public List getClasspathEntries(final IProjectFacetVersion fv) {
		ArrayList list = new ArrayList();
		if( fv.getProjectFacet().getId().equals("jst.java")) {
			IVMInstall vmInstall = JavaRuntime.getDefaultVMInstall();
			String name = vmInstall.getName();
			String typeId = vmInstall.getVMInstallType().getId();
			list.add(JavaCore.newContainerEntry(new Path(JavaRuntime.JRE_CONTAINER).append(typeId).append(name)));
		}
		
		String id = rc.getProperty("id");
		IPath containerPath = new Path("example.app.server.classpath.genericInitializer");
		IPath path = containerPath.append(id);
		path = path.append(fv.getProjectFacet().getId());
		path = path.append(fv.getVersionString());


		list.add(JavaCore.newContainerEntry(path));
		return list;
	}
}
